Documentation
¶
Overview ¶
Package nyamath includes some functions for mathmatics.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Calculate ¶ added in v1.1.1
Calculate returns the result of calculating x and y with the operator.
func CalculateU ¶ added in v1.1.1
CalculateU returns the result of calculating a with the unary.
Types ¶
type Expression ¶ added in v1.1.1
type Expression struct {
// contains filtered or unexported fields
}
Expression stores the infix, sufix and result of a math expression.
func New ¶ added in v1.1.1
func New(s string) (Expression, error)
New generates a expression from the string s.
func (Expression) Result ¶ added in v1.1.1
func (e Expression) Result() int64
Result returns the result of the expression e.
Click to show internal directories.
Click to hide internal directories.