nyamath

package module
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2018 License: MIT Imports: 0 Imported by: 0

README

nyamath

This repository holds a package including some functions for mathmatics.

Download / Install

The easiest way to install is to run go get -u github.com/catsworld/nyamath. You can also manually git clone the repository to $GOPATH/src/catsworld/nyamath.

Documentation

Overview

Package nyamath includes some functions for mathmatics.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsNumber

func IsNumber(r rune) bool

IsNumber checks if a rune is in ['0'..'9']

func Qpow

func Qpow(x, y int64) int64

Qpow calculates x^y and returns the result with the quick pow algorithm.

Types

This section is empty.

Jump to